import axios from 'axios'
import { Toast } from 'vant'
import qs from 'qs'

const Axios = axios.create({
  timeout: 60000,
  responseType: 'json',
  withCredentials: true,
  headers: {}
})

Axios.interceptors.request.use((config) => {
  Toast.loading({
    duration: 0, // 持续展示 toast
    forbidClick: true, // 禁用背景点击
    loadingType: 'spinner',
    color: 'white',
    message: '请求中'
  })
  // 处理请求data,若为get请求，拼到url后面，若为post请求，直接添加到body中
  let data = qs.stringify(config.data)
  if (config.method === 'get' || config.method === 'GET') {
    // 判断是通过斜杠传参还是通过query传参
    if (config.url.indexOf(':') > -1) {
      if (typeof config.data === 'object') {
        config.url = Object.keys(config.data).reduce((url, k) => { // 此方法对每个元素进行处理
          const re = new RegExp(`:${k}(?!w)`, 'i')
          return url.replace(re, config.data[k])
        }, config.url)
      } else {
        config.url = config.url.slice(0, config.url.indexOf(':')) + data
      }
    } else {
      config.url += '?' + data
    }
  }
  return config
}, (error) => {
  console.log(error)
})

Axios.interceptors.response.use((res) => {
  setTimeout(() => {
    Toast.clear()
  }, 500)
  if (res.status === 200) {
    return res.data
  } else {
    Toast.fail('请求失败，状态码为' + res.status)
    return res.data
  }
}, (error) => {
  Toast.fail('请求失败，服务器异常')
  setTimeout(() => {
    Toast.clear()
  }, 500)
  console.log(error)
})

export default Axios
